@@ -396,6 +396,15 @@ set_command_line_wait (GeditApp *app,
 	                        (GDestroyNotify)g_object_unref);
 }
 
+static void
+set_command_line_wait_doc (GeditDocument *doc,
+			   GeditApp      *app)
+{
+	GeditTab *tab = gedit_tab_get_from_document (doc);
+
+	set_command_line_wait (app, tab);
+}
+
 static void
 open_files (GApplication            *application,
 	    gboolean                 new_window,
@@ -466,7 +475,7 @@ open_files (GApplication            *application,
 
 		if (command_line)
 		{
-			g_slist_foreach (loaded, (GFunc)set_command_line_wait, NULL);
+			g_slist_foreach (loaded, (GFunc)set_command_line_wait_doc, GEDIT_APP (application));
 		}
 		g_slist_free (loaded);
 	}
