@@ -34,9 +34,9 @@
  * in return the list of FileItem structs.
  *
  * The recent files list can be filtered by calling
- * gedit_open_document_selector_store_set_recent_filter()
+ * gedit_open_document_selector_store_set_filter()
  * and you can get the actual filter by calling
- * gedit_open_document_selector_store_get_recent_filter()
+ * gedit_open_document_selector_store_get_filter()
  * ( this is in addition to the text mime type filter)
  *
  * The recent files list is not capped by Gedit settings like
@@ -65,14 +65,16 @@
 
 struct _GeditOpenDocumentSelectorStorePrivate
 {
-	GeditRecentConfiguration recent_config;
-	GList *recent_items;
-	gint recent_config_limit;
-	gboolean recent_items_need_update;
+	GSource                  *recent_source;
+
+	GeditRecentConfiguration  recent_config;
+	gchar                    *filter;
+	GList                    *recent_items;
+	gint                      recent_config_limit;
+	gboolean                  recent_items_need_update;
 };
 
 G_LOCK_DEFINE_STATIC (recent_files_filter_lock);
-G_LOCK_DEFINE_STATIC (store_recent_items_lock);
 
 G_DEFINE_TYPE_WITH_PRIVATE (GeditOpenDocumentSelectorStore, gedit_open_document_selector_store, G_TYPE_OBJECT)
 
@@ -521,15 +523,12 @@ update_list_cb (GeditOpenDocumentSelectorStore *selector_store,
 	switch (type)
 	{
 		case GEDIT_OPEN_DOCUMENT_SELECTOR_RECENT_FILES_LIST:
-			G_LOCK (store_recent_items_lock);
-
 			gedit_open_document_selector_free_file_items_list (selector_store->priv->recent_items);
 			selector_store->priv->recent_items = list;
 
-			DEBUG_SELECTOR (g_print ("\tStore(%p): update_list_cb: Thread:%p, type:%s, length:%i\n",
-			                         selector_store, g_thread_self (), list_type_string[type], g_list_length (list)););
+			DEBUG_SELECTOR (g_print ("\tStore(%p): update_list_cb: type:%s, length:%i\n",
+			                         selector_store, list_type_string[type], g_list_length (list)););
 
-			G_UNLOCK (store_recent_items_lock);
 			break;
 		default:
 			break;
@@ -559,6 +558,9 @@ gedit_open_document_selector_store_dispose (GObject *object)
 
 	gedit_recent_configuration_destroy (&priv->recent_config);
 
+	g_clear_pointer (&priv->recent_source, g_source_destroy);
+	g_clear_pointer (&priv->filter, g_free);
+
 	if (priv->recent_items)
 	{
 		gedit_open_document_selector_free_file_items_list (priv->recent_items);
@@ -591,6 +593,61 @@ static GList * (*list_func [])(GeditOpenDocumentSelectorStore *selector_store,
 	get_current_docs_list
 };
 
+static gboolean
+update_recent_list (gpointer user_data)
+{
+	GeditOpenDocumentSelectorStore *selector_store;
+	GeditOpenDocumentSelectorStorePrivate *priv;
+	GeditOpenDocumentSelector *selector;
+	PushMessage *message;
+	/* The type variable is only used when debug code activated */
+	G_GNUC_UNUSED ListType type;
+	GList *file_items_list;
+	GTask *task = G_TASK(user_data);
+
+	selector_store = g_task_get_source_object (task);
+	priv = selector_store->priv;
+	message = g_task_get_task_data (task);
+	selector = message->selector;
+	type = message->type;
+
+	DEBUG_SELECTOR_TIMER_DECL
+	DEBUG_SELECTOR_TIMER_NEW
+	DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: type:%s\n",
+	                         selector, list_type_string[type]););
+
+	/* Update the recent list only when it changes, copy otherwise but keep it the first time */
+	if (priv->recent_items != NULL && priv->recent_items_need_update == FALSE)
+	{
+		file_items_list = gedit_open_document_selector_copy_file_items_list (priv->recent_items);
+
+		DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: recent list copy\n", selector););
+	}
+	else
+	{
+		priv->recent_items_need_update = FALSE;
+		file_items_list = get_recent_files_list (selector_store, selector);
+
+		DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: recent list compute\n", selector););
+
+		if (priv->recent_items == NULL)
+		{
+			priv->recent_items = gedit_open_document_selector_copy_file_items_list (file_items_list);
+		}
+	}
+
+	g_task_return_pointer (task,
+	                       file_items_list,
+	                       (GDestroyNotify)gedit_open_document_selector_free_file_items_list);
+
+	DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: type:%s, time:%lf\n",
+	                         selector, list_type_string[type], DEBUG_SELECTOR_TIMER_GET););
+	DEBUG_SELECTOR_TIMER_DESTROY
+
+	priv->recent_source = NULL;
+	return G_SOURCE_REMOVE;
+}
+
 static void
 update_list_dispatcher (GTask        *task,
                         gpointer      source_object,
@@ -598,7 +655,6 @@ update_list_dispatcher (GTask        *task,
                         GCancellable *cancellable)
 {
 	GeditOpenDocumentSelectorStore *selector_store = source_object;
-	GeditOpenDocumentSelectorStorePrivate *priv = selector_store->priv;
 	GeditOpenDocumentSelector *selector;
 	PushMessage *message;
 	ListType type;
@@ -613,43 +669,6 @@ update_list_dispatcher (GTask        *task,
 	DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: Thread:%p, type:%s\n",
 	                         selector, g_thread_self (), list_type_string[type]););
 
-	/* Update the recent list only when it changes, copy otherwise but keep it the first time */
-	if (type == GEDIT_OPEN_DOCUMENT_SELECTOR_RECENT_FILES_LIST)
-	{
-		G_LOCK (store_recent_items_lock);
-
-		if (priv->recent_items != NULL && priv->recent_items_need_update == FALSE)
-		{
-			file_items_list = gedit_open_document_selector_copy_file_items_list (priv->recent_items);
-
-			DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: recent list copy\n", selector););
-		}
-		else
-		{
-			priv->recent_items_need_update = FALSE;
-			file_items_list = get_recent_files_list (selector_store, selector);
-
-			DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: recent list compute\n", selector););
-
-			if (priv->recent_items == NULL)
-			{
-				priv->recent_items = gedit_open_document_selector_copy_file_items_list (file_items_list);
-			}
-		}
-
-		G_UNLOCK (store_recent_items_lock);
-
-		g_task_return_pointer (task,
-		                       file_items_list,
-		                       (GDestroyNotify)gedit_open_document_selector_free_file_items_list);
-
-		DEBUG_SELECTOR (g_print ("\tStore(%p): store dispatcher: Thread:%p, type:%s, time:%lf\n",
-		                         selector, g_thread_self (), list_type_string[type], DEBUG_SELECTOR_TIMER_GET););
-		DEBUG_SELECTOR_TIMER_DESTROY
-
-		return;
-	}
-
 	if (type >= GEDIT_OPEN_DOCUMENT_SELECTOR_LIST_TYPE_NUM_OF_LISTS)
 	{
 		g_task_return_new_error (task,
@@ -690,6 +709,7 @@ gedit_open_document_selector_store_update_list_async (GeditOpenDocumentSelectorS
                                                       ListType                        type,
                                                       gpointer                        user_data)
 {
+	GeditOpenDocumentSelectorStorePrivate *priv;
 	GTask *task;
 	PushMessage *message;
 
@@ -699,13 +719,24 @@ gedit_open_document_selector_store_update_list_async (GeditOpenDocumentSelectorS
 	message = g_new (PushMessage, 1);
 	message->selector = selector;
 	message->type = type;
+	priv = selector_store->priv;
 
 	task = g_task_new (selector_store, cancellable, callback, user_data);
 	g_task_set_source_tag (task, gedit_open_document_selector_store_update_list_async);
 	g_task_set_priority (task, G_PRIORITY_DEFAULT);
 	g_task_set_task_data (task, message, (GDestroyNotify)g_free);
 
-	g_task_run_in_thread (task, update_list_dispatcher);
+	if (type == GEDIT_OPEN_DOCUMENT_SELECTOR_RECENT_FILES_LIST &&
+	    priv->recent_source == NULL)
+	{
+		priv->recent_source = g_idle_source_new ();
+		g_task_attach_source (task, priv->recent_source, update_recent_list);
+	}
+	else
+	{
+		g_task_run_in_thread (task, update_list_dispatcher);
+	}
+
 	g_object_unref (task);
 }
 
@@ -743,8 +774,8 @@ gedit_open_document_selector_store_get_recent_limit (GeditOpenDocumentSelectorSt
 }
 
 void
-gedit_open_document_selector_store_set_recent_filter (GeditOpenDocumentSelectorStore *store,
-                                                      gchar                          *filter)
+gedit_open_document_selector_store_set_filter (GeditOpenDocumentSelectorStore *store,
+                                               gchar                          *filter)
 {
 	gchar *old_filter;
 
@@ -753,22 +784,22 @@ gedit_open_document_selector_store_set_recent_filter (GeditOpenDocumentSelectorS
 
 	G_LOCK (recent_files_filter_lock);
 
-	old_filter = store->priv->recent_config.substring_filter;
-	store->priv->recent_config.substring_filter = filter;
+	old_filter = store->priv->filter;
+	store->priv->filter = g_strdup (filter);
 
 	G_UNLOCK (recent_files_filter_lock);
 	g_free (old_filter);
 }
 
 gchar *
-gedit_open_document_selector_store_get_recent_filter (GeditOpenDocumentSelectorStore *store)
+gedit_open_document_selector_store_get_filter (GeditOpenDocumentSelectorStore *store)
 {
 	gchar *recent_filter;
 
 	g_return_val_if_fail (GEDIT_IS_OPEN_DOCUMENT_SELECTOR_STORE (store), NULL);
 
 	G_LOCK (recent_files_filter_lock);
-	recent_filter = g_strdup (store->priv->recent_config.substring_filter);
+	recent_filter = g_strdup (store->priv->filter);
 	G_UNLOCK (recent_files_filter_lock);
 
 	return recent_filter;
