@@ -66,10 +66,10 @@ GType				 gedit_open_document_selector_store_get_type				(void) G_GNUC_CONST;
 
 gint				 gedit_open_document_selector_store_get_recent_limit			(GeditOpenDocumentSelectorStore *store);
 
-void				 gedit_open_document_selector_store_set_recent_filter			(GeditOpenDocumentSelectorStore *store,
+void				 gedit_open_document_selector_store_set_filter				(GeditOpenDocumentSelectorStore *store,
                                                                                                          gchar                          *filter);
 
-gchar				*gedit_open_document_selector_store_get_recent_filter			(GeditOpenDocumentSelectorStore *store);
+gchar				*gedit_open_document_selector_store_get_filter				(GeditOpenDocumentSelectorStore *store);
 
 GList				*gedit_open_document_selector_store_update_list_finish			(GeditOpenDocumentSelectorStore  *open_document_selector_store,
                                                                                                          GAsyncResult                    *res,
